@@ -90,3 +90,5 @@ from .absolutevalue import ULAbsoluteValue  # noqa
 from .vrcontrollervalues import ULGetVRControllerValues  # noqa
 from .vrheadsetvalues import ULGetVRHeadsetValues  # noqa
 from .storevalue import ULStoreValue  #noqa
+from .getfont import ULGetFont
+from .getuiwidgetattr import ULGetUIWidgetAttr
