@@ -14,6 +14,12 @@ class ULVectorSplitXYZ(ULParameterNode):
         self.OUTZ = ULOutSocket(self, self.get_out_z)
 
     def get_out_x(self):
+        vector = self.get_output('vector')
+        if vector is None:
+            vector = self.set_output(
+                'vector',
+                self.get_input(self.input_v)
+            )
         return self.output_v.x
 
     def get_out_y(self):
