@@ -14,7 +14,7 @@ class ULVectorXY(ULParameterNode):
     def get_out_v(self):
         x = self.get_input(self.input_x)
         y = self.get_input(self.input_y)
-        v = Vector((0, 0, 0))
+        v = Vector((0, 0))
         if not is_invalid(x):
             v.x = x
         if not is_invalid(y):
