@@ -12,7 +12,9 @@ from .letterbox import Letterbox
 from .distort import Distort
 from .droplets import Droplets
 from .blur import Blur
+from .dof import DoF
 from .chromaticaberration import ChromaticAberration
+from .sharpen import Sharpen
 from .shader import load_glsl
 from .shader import remove_filter
 from .shader import toggle_filter
