@@ -119,6 +119,14 @@ class Mist(ULFilter):
     def start(self, val):
         self.settings['start'] = float(val)
 
+    @property
+    def density(self):
+        return self.settings['density']
+
+    @density.setter
+    def density(self, val):
+        self.settings['density'] = float(val)
+
     @property
     def power(self):
         return self.settings['power']
@@ -133,6 +141,4 @@ class Mist(ULFilter):
 
     @color.setter
     def color(self, val):
-        if not isinstance(val, Vector):
-            val = Vector(val)
-        self.settings['color'] = val
+        self.settings['color'] = Vector(val).to_3d()
